/* This file is part of the KDE libraries

   Copyright (C) 2007 Daniel Laidig <d.laidig@gmx.de>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.

   This file is autogenerated by kdeutils/kcharselect/kcharselect-generate-datafile.py
*/

QT_TRANSLATE_NOOP3("KSharSelect", "European Alphabets", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "African Scripts", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Middle Eastern Scripts", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "South Asian Scripts", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Philippine Scripts", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "South East Asian Scripts", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "East Asian Scripts", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Central Asian Scripts", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Other Scripts", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Symbols", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Mathematical Symbols", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Phonetic Symbols", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Combining Diacritical Marks", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Other", "KCharSelect section name");
QT_TRANSLATE_NOOP3("KSharSelect", "Basic Latin", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Latin-1 Supplement", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Latin Extended-A", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Latin Extended-B", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "IPA Extensions", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Spacing Modifier Letters", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Combining Diacritical Marks", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Greek and Coptic", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Cyrillic", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Cyrillic Supplement", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Armenian", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Hebrew", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Arabic", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Syriac", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Arabic Supplement", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Thaana", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "NKo", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Samaritan", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Mandaic", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Devanagari", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Bengali", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Gurmukhi", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Gujarati", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Oriya", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Tamil", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Telugu", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Kannada", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Malayalam", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Sinhala", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Thai", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Lao", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Tibetan", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Myanmar", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Georgian", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Hangul Jamo", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Ethiopic", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Ethiopic Supplement", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Cherokee", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Unified Canadian Aboriginal Syllabics", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Ogham", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Runic", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Tagalog", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Hanunoo", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Buhid", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Tagbanwa", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Khmer", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Mongolian", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Unified Canadian Aboriginal Syllabics Extended", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Limbu", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Tai Le", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "New Tai Lue", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Khmer Symbols", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Buginese", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Tai Tham", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Balinese", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Sundanese", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Batak", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Lepcha", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Ol Chiki", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Vedic Extensions", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Phonetic Extensions", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Phonetic Extensions Supplement", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Combining Diacritical Marks Supplement", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Latin Extended Additional", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Greek Extended", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "General Punctuation", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Superscripts and Subscripts", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Currency Symbols", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Combining Diacritical Marks for Symbols", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Letterlike Symbols", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Number Forms", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Arrows", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Mathematical Operators", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Miscellaneous Technical", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Control Pictures", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Optical Character Recognition", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Enclosed Alphanumerics", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Box Drawing", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Block Elements", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Geometric Shapes", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Miscellaneous Symbols", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Dingbats", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Miscellaneous Mathematical Symbols-A", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Supplemental Arrows-A", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Braille Patterns", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Supplemental Arrows-B", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Miscellaneous Mathematical Symbols-B", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Supplemental Mathematical Operators", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Miscellaneous Symbols and Arrows", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Glagolitic", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Latin Extended-C", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Coptic", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Georgian Supplement", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Tifinagh", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Ethiopic Extended", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Cyrillic Extended-A", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Supplemental Punctuation", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "CJK Radicals Supplement", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Kangxi Radicals", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Ideographic Description Characters", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "CJK Symbols and Punctuation", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Hiragana", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Katakana", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Bopomofo", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Hangul Compatibility Jamo", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Kanbun", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Bopomofo Extended", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "CJK Strokes", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Katakana Phonetic Extensions", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Enclosed CJK Letters and Months", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "CJK Compatibility", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "CJK Unified Ideographs Extension A", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Yijing Hexagram Symbols", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "CJK Unified Ideographs", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Yi Syllables", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Yi Radicals", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Lisu", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Vai", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Cyrillic Extended-B", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Bamum", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Modifier Tone Letters", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Latin Extended-D", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Syloti Nagri", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Common Indic Number Forms", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Phags-pa", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Saurashtra", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Devanagari Extended", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Kayah Li", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Rejang", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Hangul Jamo Extended-A", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Javanese", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Cham", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Myanmar Extended-A", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Tai Viet", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Ethiopic Extended-A", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Meetei Mayek", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Hangul Syllables", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Hangul Jamo Extended-B", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "High Surrogates", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "High Private Use Surrogates", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Low Surrogates", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Private Use Area", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "CJK Compatibility Ideographs", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Alphabetic Presentation Forms", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Arabic Presentation Forms-A", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Variation Selectors", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Vertical Forms", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Combining Half Marks", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "CJK Compatibility Forms", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Small Form Variants", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Arabic Presentation Forms-B", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Halfwidth and Fullwidth Forms", "KCharselect unicode block name");
QT_TRANSLATE_NOOP3("KSharSelect", "Specials", "KCharselect unicode block name");
